msxml3/tests: Small spelling fix in a nonexistent resource.

Francois Gouget fgouget at free.fr
Tue Nov 2 05:50:11 CDT 2010


---

I presume that if 'urn:non-existant-foo' does not exist then 
'urn:nonexistent-foo' won't either.


 dlls/msxml3/tests/domdoc.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/dlls/msxml3/tests/domdoc.c b/dlls/msxml3/tests/domdoc.c
index fb5c4ac..f1d2c88 100644
--- a/dlls/msxml3/tests/domdoc.c
+++ b/dlls/msxml3/tests/domdoc.c
@@ -6550,8 +6550,8 @@ static void test_XSLPattern(void)
     if (len)
         expect_list_and_release(list, "E3.E3.E2.D1 E3.E4.E2.D1");
 
-    /* set prefix foo to some non-existant namespace */
-    ole_check(IXMLDOMDocument2_setProperty(doc, _bstr_("SelectionNamespaces"), _variantbstr_("xmlns:foo='urn:non-existant-foo'")));
+    /* set prefix foo to some nonexistent namespace */
+    ole_check(IXMLDOMDocument2_setProperty(doc, _bstr_("SelectionNamespaces"), _variantbstr_("xmlns:foo='urn:nonexistent-foo'")));
 
     /* the registered prefix takes precedence */
     ole_check(IXMLDOMDocument2_selectNodes(doc, _bstr_("//foo:c"), &list));
-- 
1.7.1




More information about the wine-patches mailing list